pub struct Const<I: Interner> { /* private fields */ }Expand description
Constants.
Implementations
sourceimpl<I: Interner> Const<I>
impl<I: Interner> Const<I>
sourcepub fn new(interner: I, data: impl CastTo<ConstData<I>>) -> Self
pub fn new(interner: I, data: impl CastTo<ConstData<I>>) -> Self
Create a Const using something that can be cast to const data.
sourcepub fn interned(&self) -> &I::InternedConst
pub fn interned(&self) -> &I::InternedConst
Gets the interned constant.
sourcepub fn bound_var(&self, interner: I) -> Option<BoundVar>
pub fn bound_var(&self, interner: I) -> Option<BoundVar>
If this is a ConstData::BoundVar(d), returns Some(d) else None.
sourcepub fn inference_var(&self, interner: I) -> Option<InferenceVar>
pub fn inference_var(&self, interner: I) -> Option<InferenceVar>
If this is a ConstData::InferenceVar(d), returns Some(d) else None.
sourcepub fn needs_shift(&self, interner: I) -> bool
pub fn needs_shift(&self, interner: I) -> bool
True if this const is a “bound” const, and hence needs to be shifted across binders. Meant for debug assertions.