pub struct TypeFlags(/* private fields */);Expand description
Contains flags indicating various properties of a Ty
Implementations
Sourceimpl TypeFlags
impl TypeFlags
Sourcepub const HAS_TY_INFER: Self
pub const HAS_TY_INFER: Self
Does the type contain an InferenceVar
Sourcepub const HAS_RE_INFER: Self
pub const HAS_RE_INFER: Self
Does the type contain a lifetime with an InferenceVar
Sourcepub const HAS_CT_INFER: Self
pub const HAS_CT_INFER: Self
Does the type contain a ConstValue with an InferenceVar
Sourcepub const HAS_TY_PLACEHOLDER: Self
pub const HAS_TY_PLACEHOLDER: Self
Does the type contain a Placeholder TyKind
Sourcepub const HAS_RE_PLACEHOLDER: Self
pub const HAS_RE_PLACEHOLDER: Self
Does the type contain a lifetime with a Placeholder
Sourcepub const HAS_CT_PLACEHOLDER: Self
pub const HAS_CT_PLACEHOLDER: Self
Does the type contain a ConstValue Placeholder
Sourcepub const HAS_FREE_LOCAL_REGIONS: Self
pub const HAS_FREE_LOCAL_REGIONS: Self
True when the type has free lifetimes related to a local context
Sourcepub const HAS_TY_PROJECTION: Self
pub const HAS_TY_PROJECTION: Self
Does the type contain a projection of an associated type
Sourcepub const HAS_TY_OPAQUE: Self
pub const HAS_TY_OPAQUE: Self
Does the type contain an opaque type
Sourcepub const HAS_CT_PROJECTION: Self
pub const HAS_CT_PROJECTION: Self
Does the type contain an unevaluated const projection
Sourcepub const HAS_RE_ERROR: Self
pub const HAS_RE_ERROR: Self
Does the type contain an error lifetime
Sourcepub const HAS_FREE_REGIONS: Self
pub const HAS_FREE_REGIONS: Self
Does the type contain any free lifetimes
Sourcepub const HAS_RE_LATE_BOUND: Self
pub const HAS_RE_LATE_BOUND: Self
True when the type contains lifetimes that will be substituted when function is called
Sourcepub const HAS_RE_ERASED: Self
pub const HAS_RE_ERASED: Self
True when the type contains an erased lifetime
Sourcepub const STILL_FURTHER_SPECIALIZABLE: Self
pub const STILL_FURTHER_SPECIALIZABLE: Self
Does the type contain placeholders or inference variables that could be replaced later
Sourcepub const HAS_FREE_LOCAL_NAMES: Self
pub const HAS_FREE_LOCAL_NAMES: Self
True when the type contains free names local to a particular context
Sourcepub const HAS_PROJECTION: Self
pub const HAS_PROJECTION: Self
Does the type contain any form of projection
Sourceimpl TypeFlags
impl TypeFlags
Sourcepub const fn bits(&self) -> u16
pub const fn bits(&self) -> u16
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u16) -> Option<Self>
pub const fn from_bits(bits: u16) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u16) -> Self
pub const fn from_bits_truncate(bits: u16) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u16) -> Self
pub const fn from_bits_retain(bits: u16) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl TypeFlags
impl TypeFlags
Sourcepub const fn iter(&self) -> Iter<TypeFlags>
pub const fn iter(&self) -> Iter<TypeFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<TypeFlags>
pub const fn iter_names(&self) -> IterNames<TypeFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.