VariableKinds

Struct VariableKinds 

pub struct VariableKinds<I: Interner> { /* private fields */ }
List of interned elements.

Implementations

Source

impl<I: Interner> VariableKinds<I>

pub fn inner_debug(&self, interner: I) -> VariableKindsInnerDebug<'_, I>

Helper method for debugging variable kinds.

Source

impl<I: Interner> VariableKinds<I>

pub fn interned(&self) -> &I::InternedVariableKinds

Get the interned elements.

pub fn as_slice(&self, interner: I) -> &[VariableKind<I>]

Returns a slice containing the elements.

pub fn at(&self, interner: I, index: usize) -> &VariableKind<I>

Index into the sequence.

pub fn empty(interner: I) -> Self

Create an empty sequence.

pub fn is_empty(&self, interner: I) -> bool

Check whether this is an empty sequence.

pub fn iter(&self, interner: I) -> Iter<'_, VariableKind<I>>

Get an iterator over the elements of the sequence.

pub fn len(&self, interner: I) -> usize

Get the length of the sequence.

Source

impl<I: Interner> VariableKinds<I>

pub fn from_fallible<E>( interner: I, elements: impl IntoIterator<Item = Result<impl CastTo<VariableKind<I>>, E>>, ) -> Result<Self, E>

Tries to create a sequence using an iterator of element-like things.

pub fn from_iter( interner: I, elements: impl IntoIterator<Item = impl CastTo<VariableKind<I>>>, ) -> Self

Create a sequence from elements

pub fn from1(interner: I, element: impl CastTo<VariableKind<I>>) -> Self

Create a sequence from a single element.