pub struct VariableKinds<I: Interner> { /* private fields */ }Expand description
List of interned elements.
Implementations
Sourceimpl<I: Interner> VariableKinds<I>
impl<I: Interner> VariableKinds<I>
Sourcepub fn inner_debug(&self, interner: I) -> VariableKindsInnerDebug<'_, I>
pub fn inner_debug(&self, interner: I) -> VariableKindsInnerDebug<'_, I>
Helper method for debugging variable kinds.
Sourceimpl<I: Interner> VariableKinds<I>
impl<I: Interner> VariableKinds<I>
Sourcepub fn interned(&self) -> &I::InternedVariableKinds
pub fn interned(&self) -> &I::InternedVariableKinds
Get the interned elements.
Sourcepub fn as_slice(&self, interner: I) -> &[VariableKind<I>]
pub fn as_slice(&self, interner: I) -> &[VariableKind<I>]
Returns a slice containing the elements.
Sourcepub fn at(&self, interner: I, index: usize) -> &VariableKind<I>
pub fn at(&self, interner: I, index: usize) -> &VariableKind<I>
Index into the sequence.
Sourcepub fn iter(&self, interner: I) -> Iter<'_, VariableKind<I>>
pub fn iter(&self, interner: I) -> Iter<'_, VariableKind<I>>
Get an iterator over the elements of the sequence.
Sourceimpl<I: Interner> VariableKinds<I>
impl<I: Interner> VariableKinds<I>
Sourcepub fn from_fallible<E>(
interner: I,
elements: impl IntoIterator<Item = Result<impl CastTo<VariableKind<I>>, E>>,
) -> Result<Self, E>
pub fn from_fallible<E>( interner: I, elements: impl IntoIterator<Item = Result<impl CastTo<VariableKind<I>>, E>>, ) -> Result<Self, E>
Tries to create a sequence using an iterator of element-like things.
Sourcepub fn from_iter(
interner: I,
elements: impl IntoIterator<Item = impl CastTo<VariableKind<I>>>,
) -> Self
pub fn from_iter( interner: I, elements: impl IntoIterator<Item = impl CastTo<VariableKind<I>>>, ) -> Self
Create a sequence from elements
Sourcepub fn from1(interner: I, element: impl CastTo<VariableKind<I>>) -> Self
pub fn from1(interner: I, element: impl CastTo<VariableKind<I>>) -> Self
Create a sequence from a single element.